@@ -1,6 +1,6 @@
 package Langertha::Role::Chat;
 # ABSTRACT: Role for APIs with normal chat functionality
-our $VERSION = '0.300';
+our $VERSION = '0.301';
 use Moose::Role;
 use Future::AsyncAwait;
 use Carp qw( croak );
@@ -51,7 +51,11 @@ sub simple_chat {
     ref $self, scalar @messages, $self->chat_model // 'default');
   my $request = $self->chat(@messages);
   my $response = $self->user_agent->request($request);
-  return $request->response_call->($response);
+  my $result = $request->response_call->($response);
+  if ($self->can('has_rate_limit') && $self->has_rate_limit && ref $result && $result->isa('Langertha::Response')) {
+    $result = $result->clone_with(rate_limit => $self->rate_limit);
+  }
+  return $result;
 }
 
 
@@ -122,7 +126,11 @@ async sub simple_chat_f {
     die "".(ref $self)." request failed: ".$response->status_line;
   }
 
-  return $request->response_call->($response);
+  my $result = $request->response_call->($response);
+  if ($self->can('has_rate_limit') && $self->has_rate_limit && ref $result && $result->isa('Langertha::Response')) {
+    $result = $result->clone_with(rate_limit => $self->rate_limit);
+  }
+  return $result;
 }
 
 
@@ -233,7 +241,7 @@ Langertha::Role::Chat - Role for APIs with normal chat functionality
 
 =head1 VERSION
 
-version 0.300
+version 0.301
 
 =head1 SYNOPSIS
 
