@@ -1,6 +1,6 @@
 package Langertha::Role::HTTP;
 # ABSTRACT: Role for HTTP APIs
-our $VERSION = '0.300';
+our $VERSION = '0.301';
 use Moose::Role;
 
 use Carp qw( croak );
@@ -79,6 +79,7 @@ sub parse_response {
     $log->errorf("[%s] HTTP %s", ref $self, $response->status_line);
     croak "".(ref $self)." request failed: ".($response->status_line);
   }
+  $self->_update_rate_limit($response) if $self->can('_update_rate_limit');
   $log->tracef("[%s] Response: %s", ref $self, $response->decoded_content);
   return $self->json->decode($response->decoded_content);
 }
@@ -146,7 +147,7 @@ Langertha::Role::HTTP - Role for HTTP APIs
 
 =head1 VERSION
 
-version 0.300
+version 0.301
 
 =head2 url
 
@@ -186,7 +187,9 @@ Basic authentication is set automatically.
     my $data = $engine->parse_response($http_response);
 
 Decodes a successful L<HTTP::Response> body as JSON and returns the data
-structure. Croaks with the HTTP status line on failure.
+structure. Croaks with the HTTP status line on failure. If the engine
+supports rate limiting, extracts rate limit headers via
+C<_update_rate_limit> before decoding the body.
 
 =head2 user_agent_timeout
 
