@@ -1,6 +1,6 @@
 package Langertha::Role::OpenAICompatible;
 # ABSTRACT: Role for OpenAI-compatible API format
-our $VERSION = '0.300';
+our $VERSION = '0.301';
 use Moose::Role;
 use File::ShareDir::ProjectDistDir qw( :all );
 use Carp qw( croak );
@@ -290,6 +290,34 @@ sub simple_image {
 }
 
 
+sub _parse_rate_limit_headers {
+  my ( $self, $http_response ) = @_;
+  my %raw;
+  for my $name (qw(
+    x-ratelimit-limit-requests
+    x-ratelimit-remaining-requests
+    x-ratelimit-reset-requests
+    x-ratelimit-limit-tokens
+    x-ratelimit-remaining-tokens
+    x-ratelimit-reset-tokens
+  )) {
+    my $val = $http_response->header($name);
+    $raw{$name} = $val if defined $val;
+  }
+  return undef unless %raw;
+  require Langertha::RateLimit;
+  return Langertha::RateLimit->new(
+    ( defined $raw{'x-ratelimit-limit-requests'}     ? ( requests_limit     => $raw{'x-ratelimit-limit-requests'} + 0 )     : () ),
+    ( defined $raw{'x-ratelimit-remaining-requests'} ? ( requests_remaining => $raw{'x-ratelimit-remaining-requests'} + 0 ) : () ),
+    ( defined $raw{'x-ratelimit-reset-requests'}     ? ( requests_reset     => $raw{'x-ratelimit-reset-requests'} )         : () ),
+    ( defined $raw{'x-ratelimit-limit-tokens'}       ? ( tokens_limit       => $raw{'x-ratelimit-limit-tokens'} + 0 )       : () ),
+    ( defined $raw{'x-ratelimit-remaining-tokens'}   ? ( tokens_remaining   => $raw{'x-ratelimit-remaining-tokens'} + 0 )   : () ),
+    ( defined $raw{'x-ratelimit-reset-tokens'}       ? ( tokens_reset       => $raw{'x-ratelimit-reset-tokens'} )           : () ),
+    raw => \%raw,
+  );
+}
+
+
 
 1;
 
@@ -305,7 +333,7 @@ Langertha::Role::OpenAICompatible - Role for OpenAI-compatible API format
 
 =head1 VERSION
 
-version 0.300
+version 0.301
 
 =head1 SYNOPSIS
 
@@ -355,7 +383,8 @@ B<Engines should also compose these roles:>
 B<Engines using this role:> L<Langertha::Engine::OpenAI>, L<Langertha::Engine::DeepSeek>,
 L<Langertha::Engine::Groq>, L<Langertha::Engine::Mistral>, L<Langertha::Engine::vLLM>,
 L<Langertha::Engine::NousResearch>, L<Langertha::Engine::Perplexity>,
-L<Langertha::Engine::OllamaOpenAI>, L<Langertha::Engine::AKIOpenAI>.
+L<Langertha::Engine::HuggingFace>, L<Langertha::Engine::OllamaOpenAI>,
+L<Langertha::Engine::AKIOpenAI>.
 
 =head2 api_key
 
@@ -537,10 +566,18 @@ C<revised_prompt>.
 Sends an image generation request and returns the result. Blocks until
 the request completes. Returns an ArrayRef of image objects.
 
+=head2 _parse_rate_limit_headers
+
+Parses C<x-ratelimit-*> headers from the HTTP response into a
+L<Langertha::RateLimit> object. Covers OpenAI, Groq, Cerebras, OpenRouter,
+Replicate, and all other OpenAI-compatible engines.
+
 =head1 SEE ALSO
 
 =over
 
+=item * L<Langertha::RateLimit> - Normalized rate limit data
+
 =item * L<Langertha::Engine::OpenAI> - OpenAI engine
 
 =item * L<Langertha::Engine::DeepSeek> - DeepSeek engine
